@@ -1,9 +1,16 @@
 package Perl6::Doc;
+BEGIN {
+  $Perl6::Doc::AUTHORITY = 'cpan:HINRIK';
+}
+BEGIN {
+  $Perl6::Doc::VERSION = '0.46';
+}
 use strict;
-use warnings;
-our $VERSION = '0.45';
+use warnings FATAL => 'all';
 
-=encoding UTF-8
+1;
+
+=encoding utf8
 
 =head1 NAME
 
@@ -74,7 +81,7 @@ L<http://www.perl.com> and L<http://www.perl-magazin.de/>.
 
 =head2 Perl 6 Table Index
 
-A Pod-ified version of L<http://www.perlfoundation.org/perl6/index.cgi?perl_table_index>
+A Pod-ified version of L<http://www.perlfoundation.org/perl6/index.cgi?perl_6_index_tablet>
 is included.
 
 =head2 Man pages
@@ -84,7 +91,8 @@ Currently included are draft versions of F<perlintro> and F<perlsyn>.
 =head1 HISTORY
 
 As of version 0.40, this distribution has been overhauled and is no longer
-maintained by Herbert Breunung.
+maintained by Herbert Breunung, who originally took it over from ingy and
+audreyt.
 
 =head1 PACKAGING
 
